@@ -3,12 +3,14 @@ from __future__ import annotations
 import os
 from pathlib import Path
 
-import vapoursynth as vs
-from vsexprtools import ExprOp, VSFunction, combine, expect_bits
-from vsutil import depth, disallow_variable_format, get_depth, get_peak_value, get_y, insert_clip, iterate
+from vsexprtools import ExprOp, combine
+from vstools import (
+    FrameRangeN, FrameRangesN, VSFunction, core, depth, disallow_variable_format, expect_bits, get_depth,
+    get_peak_value, get_y, insert_clip, iterate, vs
+)
 
 from .misc import source as stgsource
-from .types import MaskCredit, Range
+from .types import MaskCredit
 
 __all__ = [
     'adg_mask',
@@ -20,8 +22,6 @@ __all__ = [
     'freeze_replace_mask'
 ]
 
-core = vs.core
-
 
 @disallow_variable_format
 def adg_mask(clip: vs.VideoNode, luma_scaling: float = 8.0, relative: bool = False) -> vs.VideoNode:
@@ -41,7 +41,7 @@ def adg_mask(clip: vs.VideoNode, luma_scaling: float = 8.0, relative: bool = Fal
 
     is_integer = y.format.sample_type == vs.INTEGER
 
-    x_string, aft_int = (f'x {peak} / ', f' {peak} *') if is_integer else ('x ', '')
+    x_string, aft_int = (f'x {peak} / ', f' {peak} * 0.5 +') if is_integer else ('x ', '')
 
     if relative:
         x_string += 'Y! Y@ 0.5 < x.PMin 0 max 0.5 / log Y@ * x.PMax 1.0 min 0.5 / log Y@ * ? '
@@ -73,7 +73,7 @@ def perform_masks_credit(path: Path) -> list[MaskCredit]:
 
 
 def to_gray(clip: vs.VideoNode, ref: vs.VideoNode) -> vs.VideoNode:
-    return core.std.AssumeFPS(clip, ref).resize.Point(format=vs.GRAY16)
+    return clip.std.AssumeFPS(ref).resize.Point(format=vs.GRAY16)
 
 
 def manual_masking(
@@ -136,7 +136,7 @@ def detail_mask(
     pf_sigma: float | None = 1.0, brz: tuple[int, int] = (2500, 4500),
     rg_mode: int = 17
 ) -> vs.VideoNode:
-    bits, clip = expect_bits(clip)
+    clip, bits = expect_bits(clip)
 
     clip_y = get_y(clip)
 
@@ -168,7 +168,7 @@ def squaremask(clip: vs.VideoNode, width: int, height: int, offset_x: int, offse
 
     white = 1 if mask_format.sample_type == vs.FLOAT else (1 << bits) - 1
 
-    white_clip = core.std.BlankClip(clip, width, height, mask_format.id, 1, color=white, keep=True)
+    white_clip = clip.std.BlankClip(width, height, mask_format.id, 1, color=white, keep=True)
 
     padded = white_clip.std.AddBorders(
         offset_x, src_w - width - offset_x,
@@ -181,7 +181,7 @@ def squaremask(clip: vs.VideoNode, width: int, height: int, offset_x: int, offse
 @disallow_variable_format
 def replace_squaremask(
     clipa: vs.VideoNode, clipb: vs.VideoNode, mask_params: tuple[int, int, int, int],
-    ranges: Range | list[Range] | None = None,
+    ranges: FrameRangeN | FrameRangesN | None = None,
     blur_sigma: float | None = None, invert: bool = False
 ) -> vs.VideoNode:
     try:
