@@ -1,23 +1,14 @@
 from __future__ import annotations
 
-from typing import Any, NamedTuple, Protocol, SupportsFloat, Tuple, TypeAlias, TypeVar
+from typing import Any, NamedTuple, Protocol, SupportsFloat
 
-import vapoursynth as vs
-from vsexprtools import SingleOrArr
+from vstools import SingleOrArr, vs
 
 __all__ = [
-    'T', 'R',
-    'Range',
     'DebanderFN',
     'MaskCredit'
 ]
 
-T = TypeVar('T')
-R = TypeVar('R')
-
-
-Range: TypeAlias = int | Tuple[int | None, int | None] | None
-
 
 class DebanderFN(Protocol):
     def __call__(
